/**
 * A queue that executes async tasks in order like mutex and semaphore methodology
 *
 * @example
 * ```ts
 * const queue = new AsyncQueue();
 *
 * function longTask() {
 *   queue.push('longTaskId', async () => {
 *     // ...
 *   });
 * }
 * ```
 */
export declare class AsyncQueue {
    /**
     * A record of task IDs and their corresponding last queued task promises.
     */
    private queue__;
    /**
     * Push a async task to the queue.
     *
     * @param taskId task id
     * @param task async task
     * @returns A promise that resolves when the task is done.
     *
     * @example
     * ```typescript
     * const queue = new AsyncQueue();
     *
     * function longTask() {
     *  queue.push('longTaskId', async () => {
     *   // ...
     * });
     * ```
     */
    push(taskId: string, task: () => Promise<void>): Promise<void>;
    /**
     * Check if the task running in the queue.
     *
     * @param taskId task id
     * @returns true if the task is running, otherwise false.
     */
    isRunning(taskId: string): boolean;
}
//# sourceMappingURL=main.d.ts.map